==> jc-1.4.0.tar.gz: soot/CompilationDeathException.h <==
// public class soot.CompilationDeathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 86ca635dd76622c4 soot_CompilationDeathException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_CompilationDeathException_H_
#define _JC_soot_CompilationDeathException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_CompilationDeathException$sub_refs	_jc_soot_CompilationDeathException$sub_refs;
typedef struct _jc_soot_CompilationDeathException$sub_nonrefs	_jc_soot_CompilationDeathException$sub_nonrefs;
typedef struct _jc_soot_CompilationDeathException$refs	_jc_soot_CompilationDeathException$refs;
typedef struct _jc_soot_CompilationDeathException$nonrefs	_jc_soot_CompilationDeathException$nonrefs;
typedef struct _jc_soot_CompilationDeathException$object	_jc_soot_CompilationDeathException$object;

typedef struct _jc_soot_CompilationDeathException$fields_struct	_jc_soot_CompilationDeathException$fields_struct;
typedef const struct _jc_soot_CompilationDeathException$vmethods	_jc_soot_CompilationDeathException$vmethods;
typedef const struct _jc_soot_CompilationDeathException$vtable	_jc_soot_CompilationDeathException$vtable;
typedef const struct _jc_soot_CompilationDeathException$vtype	_jc_soot_CompilationDeathException$vtype;

// Class fields structure
struct _jc_soot_CompilationDeathException$fields_struct {
	jint	COMPILATION__5fABORTED;
	jint	COMPILATION__5fSUCCEEDED;
};
extern _jc_soot_CompilationDeathException$fields_struct _jc_soot_CompilationDeathException$class_fields;

// Constructors
extern void _jc_soot_CompilationDeathException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_CompilationDeathException$object *, jint);
extern void _jc_soot_CompilationDeathException$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_CompilationDeathException$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_CompilationDeathException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_soot_CompilationDeathException$object *);
extern jint _jc_soot_CompilationDeathException$method$getStatus$033d8b58cdae6706(_jc_env *, struct _jc_soot_CompilationDeathException$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_CompilationDeathException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_soot_CompilationDeathException$method_info$getStatus$033d8b58cdae6706;

// Virtual methods structure
struct _jc_soot_CompilationDeathException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_soot_CompilationDeathException$object *);
	jint	(*getStatus$033d8b58cdae6706)(_jc_env *, struct _jc_soot_CompilationDeathException$object *);
};

// Vtable
struct _jc_soot_CompilationDeathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_CompilationDeathException$vmethods	soot_CompilationDeathException;
};

// Vtype
struct _jc_soot_CompilationDeathException$vtype {
	_jc_type			type;
	_jc_soot_CompilationDeathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_CompilationDeathException$sub_refs {
	struct _jc_java_lang_String$object	*mMsg;
};

// Reference instance fields (object)
struct _jc_soot_CompilationDeathException$refs {
    _jc_soot_CompilationDeathException$sub_refs	soot_CompilationDeathException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_CompilationDeathException$sub_nonrefs {
	jint	mStatus;
};

// Non-reference instance fields (object)
struct _jc_soot_CompilationDeathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_CompilationDeathException$sub_nonrefs	soot_CompilationDeathException;
};

// Object instance structure
struct _jc_soot_CompilationDeathException$object {
	_jc_soot_CompilationDeathException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_CompilationDeathException$vtype	*vtype;
	_jc_soot_CompilationDeathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_CompilationDeathException$vtype _jc_soot_CompilationDeathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_CompilationDeathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_CompilationDeathException$class_object;

#endif	/* _JC_soot_CompilationDeathException_H_ */

==> jc-1.4.6.tar.gz: soot/CompilationDeathException.h <==
// public class soot.CompilationDeathException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 86ca635dd76622c4 soot_CompilationDeathException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_CompilationDeathException_H_
#define _JC_soot_CompilationDeathException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_CompilationDeathException$sub_refs	_jc_soot_CompilationDeathException$sub_refs;
typedef struct _jc_soot_CompilationDeathException$sub_nonrefs	_jc_soot_CompilationDeathException$sub_nonrefs;
typedef struct _jc_soot_CompilationDeathException$refs	_jc_soot_CompilationDeathException$refs;
typedef struct _jc_soot_CompilationDeathException$nonrefs	_jc_soot_CompilationDeathException$nonrefs;
typedef struct _jc_soot_CompilationDeathException$object	_jc_soot_CompilationDeathException$object;

typedef struct _jc_soot_CompilationDeathException$fields_struct	_jc_soot_CompilationDeathException$fields_struct;
typedef const struct _jc_soot_CompilationDeathException$vmethods	_jc_soot_CompilationDeathException$vmethods;
typedef const struct _jc_soot_CompilationDeathException$vtable	_jc_soot_CompilationDeathException$vtable;
typedef const struct _jc_soot_CompilationDeathException$vtype	_jc_soot_CompilationDeathException$vtype;

// Class fields structure
struct _jc_soot_CompilationDeathException$fields_struct {
	jint	COMPILATION__5fABORTED;
	jint	COMPILATION__5fSUCCEEDED;
};
extern _jc_soot_CompilationDeathException$fields_struct _jc_soot_CompilationDeathException$class_fields;

// Constructors
extern void _jc_soot_CompilationDeathException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_CompilationDeathException$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_CompilationDeathException$method$_init$206934d97c5ba451(_jc_env *, struct _jc_soot_CompilationDeathException$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_CompilationDeathException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_soot_CompilationDeathException$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_CompilationDeathException$method$getStatus$033d8b58cdae6706(_jc_env *, struct _jc_soot_CompilationDeathException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_CompilationDeathException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_soot_CompilationDeathException$method_info$getStatus$033d8b58cdae6706;

// Virtual methods structure
struct _jc_soot_CompilationDeathException$vmethods {
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_soot_CompilationDeathException$object *) _JC_JCNI_ATTR;
	jint	(*getStatus$033d8b58cdae6706)(_jc_env *, struct _jc_soot_CompilationDeathException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_CompilationDeathException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_CompilationDeathException$vmethods	soot_CompilationDeathException;
};

// Vtype
struct _jc_soot_CompilationDeathException$vtype {
	_jc_type			type;
	_jc_soot_CompilationDeathException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_CompilationDeathException$sub_refs {
	struct _jc_java_lang_String$object	*mMsg;
};

// Reference instance fields (object)
struct _jc_soot_CompilationDeathException$refs {
    _jc_soot_CompilationDeathException$sub_refs	soot_CompilationDeathException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_CompilationDeathException$sub_nonrefs {
	jint	mStatus;
};

// Non-reference instance fields (object)
struct _jc_soot_CompilationDeathException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_CompilationDeathException$sub_nonrefs	soot_CompilationDeathException;
};

// Object instance structure
struct _jc_soot_CompilationDeathException$object {
	_jc_soot_CompilationDeathException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_CompilationDeathException$vtype	*vtype;
	_jc_soot_CompilationDeathException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_CompilationDeathException$vtype _jc_soot_CompilationDeathException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_CompilationDeathException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_CompilationDeathException$class_object;

#endif	/* _JC_soot_CompilationDeathException_H_ */
